@@ -6,7 +6,7 @@ from itertools import zip_longest
 from math import ceil, log2
 from typing import Any, Callable, overload
 
-from vskernels import Catrom, Kernel, Scaler
+from vskernels import Catrom, Kernel, KernelT, Scaler, ScalerT
 from vstools import core, inject_self, vs
 
 from .enums import AADirection
@@ -21,7 +21,10 @@ __all__ = [
 class _SingleInterpolate:
     _shift: float
 
-    def _interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
+    def __post_init__(self) -> None:
+        ...
+
+    def interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
         raise NotImplementedError
 
 
@@ -30,11 +33,14 @@ class _Antialiaser(_SingleInterpolate):
     field: int = dc_field(default=0, kw_only=True)
     drop_fields: bool = dc_field(default=True, kw_only=True)
     transpose_first: bool = dc_field(default=False, kw_only=True)
-    shifter: Kernel = dc_field(default=Catrom(), kw_only=True)
-    scaler: Scaler | None = dc_field(default=None, kw_only=True)
+    shifter: KernelT = dc_field(default=Catrom(), kw_only=True)
+    scaler: ScalerT | None = dc_field(default=None, kw_only=True)
 
     def __post_init__(self) -> None:
-        ...
+        super().__post_init__()
+
+        self._shifter = Kernel.ensure_obj(self.shifter, self.__class__)
+        self._scaler = None if self.scaler is None else Scaler.ensure_obj(self.scaler, self.__class__)
 
     def preprocess_clip(self, clip: vs.VideoNode) -> vs.VideoNode:
         return clip
@@ -42,7 +48,7 @@ class _Antialiaser(_SingleInterpolate):
     def get_aa_args(self, clip: vs.VideoNode, **kwargs: Any) -> dict[str, Any]:
         return {}
 
-    def _shift_interpolated(self, clip: vs.VideoNode, inter: vs.VideoNode, double_y: bool) -> vs.VideoNode:
+    def shift_interpolate(self, clip: vs.VideoNode, inter: vs.VideoNode, double_y: bool) -> vs.VideoNode:
         if double_y:
             return inter
         elif self.drop_fields:
@@ -50,17 +56,17 @@ class _Antialiaser(_SingleInterpolate):
 
         shift = (self._shift * int(not self.field), 0)
 
-        if self.scaler:
-            return self.scaler.scale(inter, clip.width, clip.height, shift)
+        if self._scaler:
+            return self._scaler.scale(inter, clip.width, clip.height, shift)
 
-        return self.shifter.scale(inter, clip.width, clip.height, shift)
+        return self._shifter.scale(inter, clip.width, clip.height, shift)
 
 
 class _FullInterpolate(_SingleInterpolate):
-    def _full_interpolate_enabled(self, x: bool, y: bool) -> bool:
+    def is_full_interpolate_enabled(self, x: bool, y: bool) -> bool:
         return False
 
-    def _full_interpolate(self, clip: vs.VideoNode, double_y: bool, double_x: bool, **kwargs: Any) -> vs.VideoNode:
+    def full_interpolate(self, clip: vs.VideoNode, double_y: bool, double_x: bool, **kwargs: Any) -> vs.VideoNode:
         raise NotImplementedError
 
 
@@ -69,7 +75,7 @@ class SuperSampler(_Antialiaser, Scaler):
         return {}
 
     @inject_self
-    def scale(
+    def scale(  # type: ignore[override]
         self, clip: vs.VideoNode, width: int, height: int, shift: tuple[float, float] = (0, 0), **kwargs: Any
     ) -> vs.VideoNode:
         clip = self.preprocess_clip(clip)
@@ -98,14 +104,14 @@ class SuperSampler(_Antialiaser, Scaler):
                 upscaled = upscaled.std.Transpose()
 
         for (y, x) in zip_longest([True] * mult_y, [True] * mult_x, fillvalue=False):
-            if isinstance(self, _FullInterpolate) and self._full_interpolate_enabled(x, y):
-                upscaled = self._full_interpolate(upscaled, y, x, **kwargs)
+            if isinstance(self, _FullInterpolate) and self.is_full_interpolate_enabled(x, y):
+                upscaled = self.full_interpolate(upscaled, y, x, **kwargs)
             else:
                 for isx, val in enumerate([y, x]):
                     if val:
                         _transpose(True, isx, y, x)
 
-                        upscaled = self._interpolate(upscaled, True, **kwargs)
+                        upscaled = self.interpolate(upscaled, True, **kwargs)
 
                         _transpose(False, isx, y, x)
 
@@ -132,14 +138,14 @@ class SuperSampler(_Antialiaser, Scaler):
                     elif cdivw == 2 and cdivh == 1:
                         cleftshift -= 0.125 * 3
 
-            upscaled = self.shifter.shift(
+            upscaled = self._shifter.shift(
                 upscaled, [topshift, ctopshift], [leftshift, cleftshift]
             )
 
-        if self.scaler:
-            return self.scaler.scale(upscaled, width, height, shift)
+        if self._scaler:
+            return self._scaler.scale(upscaled, width, height, shift)
 
-        return self.shifter.scale(upscaled, width, height, shift)
+        return self._shifter.scale(upscaled, width, height, shift)
 
 
 class SingleRater(_Antialiaser):
@@ -183,10 +189,10 @@ class SingleRater(_Antialiaser):
             if val:
                 _transpose(True, isx)
 
-                if isinstance(self, _FullInterpolate) and self._full_interpolate_enabled(x, y):
-                    upscaled = self._full_interpolate(upscaled, False, False, **kwargs)
+                if isinstance(self, _FullInterpolate) and self.is_full_interpolate_enabled(x, y):
+                    upscaled = self.full_interpolate(upscaled, False, False, **kwargs)
                 else:
-                    upscaled = self._interpolate(upscaled, False, **kwargs)
+                    upscaled = self.interpolate(upscaled, False, **kwargs)
 
                 _transpose(False, isx)
 
@@ -212,7 +218,7 @@ class DoubleRater(SingleRater):
 
 class Antialiaser(DoubleRater, SuperSampler):
     @inject_self
-    def scale(
+    def scale(  # type: ignore[override]
         self, clip: vs.VideoNode, width: int, height: int, shift: tuple[float, float] = (0, 0), **kwargs: Any
     ) -> vs.VideoNode:
         """Scale with this antialiaser"""
