@@ -25,7 +25,7 @@ class EEDI2(_FullInterpolate, _Antialiaser):
 
     cuda: bool = dc_field(default=False, kw_only=True)
 
-    def _full_interpolate_enabled(self, x: bool, y: bool) -> bool:
+    def is_full_interpolate_enabled(self, x: bool, y: bool) -> bool:
         return self.cuda and x and y
 
     def get_aa_args(self, clip: vs.VideoNode, **kwargs: Any) -> dict[str, Any]:
@@ -34,7 +34,7 @@ class EEDI2(_FullInterpolate, _Antialiaser):
             estr=self.estr, dstr=self.dstr, maxd=self.maxd, pp=self.pp
         )
 
-    def _interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
+    def interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
         if self.cuda:
             interpolated = core.eedi2cuda.EEDI2(clip, self.field, **kwargs)
         else:
@@ -45,16 +45,16 @@ class EEDI2(_FullInterpolate, _Antialiaser):
         elif self.drop_fields:
             interpolated = interpolated.std.SeparateFields(not self.field)[::2]
 
-            return self.shifter.shift(interpolated, (0.5 - 0.75 * self.field, 0))
+            return self._shifter.shift(interpolated, (0.5 - 0.75 * self.field, 0))
 
         shift = (self._shift * int(not self.field), 0)
 
-        if self.scaler:
-            return self.scaler.scale(interpolated, clip.width, clip.height, shift)
+        if self._scaler:
+            return self._scaler.scale(interpolated, clip.width, clip.height, shift)
 
-        return self.shifter.scale(interpolated, clip.width, clip.height, shift)
+        return self._shifter.scale(interpolated, clip.width, clip.height, shift)
 
-    def _full_interpolate(self, clip: vs.VideoNode, double_y: bool, double_x: bool, **kwargs: Any) -> vs.VideoNode:
+    def full_interpolate(self, clip: vs.VideoNode, double_y: bool, double_x: bool, **kwargs: Any) -> vs.VideoNode:
         return core.eedi2cuda.Enlarge2(clip, **kwargs)
 
     _shift = -0.5
