@@ -39,8 +39,12 @@ class EEDI3(_Antialiaser):
     def __post_init__(self) -> None:
         super().__post_init__()
 
+        self._sclip_aa: Antialiaser | None
+
         if self.sclip_aa and not isinstance(self.sclip_aa, Antialiaser):
-            self.sclip_aa = self.sclip_aa()
+            self._sclip_aa = self.sclip_aa()
+        else:
+            self._sclip_aa = self.sclip_aa  # type: ignore[assignment]
 
     def get_aa_args(self, clip: vs.VideoNode, **kwargs: Any) -> dict[str, Any]:
         args = dict(
@@ -56,28 +60,28 @@ class EEDI3(_Antialiaser):
 
         return args
 
-    def _interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
+    def interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
         aa_kwargs = self.get_aa_args(clip, **kwargs)
 
-        if self.sclip_aa and ((('sclip' in kwargs) and not kwargs['sclip']) or 'sclip' not in kwargs):
-            sclip_args = self.sclip_aa.get_aa_args(clip)
+        if self._sclip_aa and ((('sclip' in kwargs) and not kwargs['sclip']) or 'sclip' not in kwargs):
+            sclip_args = self._sclip_aa.get_aa_args(clip)
 
             if double_y:
-                sclip_args |= self.sclip_aa.get_ss_args(clip)
+                sclip_args |= self._sclip_aa.get_ss_args(clip)
             else:
-                sclip_args |= self.sclip_aa.get_sr_args(clip)
+                sclip_args |= self._sclip_aa.get_sr_args(clip)
 
             aa_kwargs.update(
-                sclip=self.sclip_aa._interpolate(clip, double_y or not self.drop_fields, **sclip_args)
+                sclip=self._sclip_aa.interpolate(clip, double_y or not self.drop_fields, **sclip_args)
             )
 
         function = core.eedi3m.EEDI3CL if self.opencl else core.eedi3m.EEDI3
 
-        interpolated = function(
+        interpolated = function(  # type: ignore[operator]
             clip, self.field, double_y or not self.drop_fields, **aa_kwargs
         )
 
-        return self._shift_interpolated(clip, interpolated, double_y)
+        return self.shift_interpolate(clip, interpolated, double_y)
 
     _shift = 0.5
 
