@@ -25,12 +25,12 @@ class SANGNOM(_Antialiaser):
     def get_aa_args(self, clip: vs.VideoNode, **kwargs: Any) -> dict[str, Any]:
         return dict(aa=self.aa_strength, order=0 if self.double_fps else self.field + 1)
 
-    def _interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
+    def interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
         interpolated = core.sangnom.SangNom(
             clip, dh=double_y or not self.drop_fields, **kwargs
         )
 
-        return self._shift_interpolated(clip, interpolated, double_y)
+        return self.shift_interpolate(clip, interpolated, double_y)
 
     _shift = -0.5
 
